==> manaplus_1.5.8.1.orig.tar.xz: manaplus-1.5.8.1/src/particle/animationparticle.cpp <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2006-2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011-2015  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "particle/animationparticle.h"

#include "simpleanimation.h"

#include "utils/delete2.h"

#include "debug.h"

AnimationParticle::AnimationParticle(Animation *const animation) :
    ImageParticle(nullptr),
    mAnimation(new SimpleAnimation(animation))
{
}

AnimationParticle::AnimationParticle(XmlNodePtrConst animationNode,
                                     const std::string& dyePalettes) :
    ImageParticle(nullptr),
    mAnimation(new SimpleAnimation(animationNode, dyePalettes))
{
}

AnimationParticle::~AnimationParticle()
{
    delete2(mAnimation);
    mImage = nullptr;
}

bool AnimationParticle::update()
{
    if (mAnimation)
    {
        mAnimation->update(10);  // particle engine is updated every 10ms
        mImage = mAnimation->getCurrentImage();
    }
    return Particle::update();
}

==> manaplus_1.6.1.2.orig.tar.xz: manaplus-1.6.1.2/src/particle/animationparticle.cpp <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2006-2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011-2015  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "particle/animationparticle.h"

#include "resources/animation/simpleanimation.h"

#include "utils/delete2.h"

#include "debug.h"

AnimationParticle::AnimationParticle(Animation *restrict const animation) :
    ImageParticle(nullptr),
    mAnimation(new SimpleAnimation(animation))
{
}

AnimationParticle::AnimationParticle(XmlNodePtrConst animationNode,
                                     const std::string &restrict dyePalettes) :
    ImageParticle(nullptr),
    mAnimation(new SimpleAnimation(animationNode, dyePalettes))
{
}

AnimationParticle::~AnimationParticle()
{
    delete2(mAnimation);
    mImage = nullptr;
}

bool AnimationParticle::update() restrict2
{
    if (mAnimation)
    {
        mAnimation->update(10);  // particle engine is updated every 10ms
        mImage = mAnimation->getCurrentImage();
    }
    return Particle::update();
}
